@@ -18,7 +18,7 @@ BEGIN {
   $Bio::Tools::Primer3Redux::Result::AUTHORITY = 'cpan:CJFIELDS';
 }
 BEGIN {
-  $Bio::Tools::Primer3Redux::Result::VERSION = '0.03';
+  $Bio::Tools::Primer3Redux::Result::VERSION = '0.04';
 }
 
 use strict;
@@ -158,6 +158,21 @@ sub run_parameter {
 }
 
 
+
+sub warnings {
+  my $self = shift;
+  my $warning_value = $self->run_parameter('PRIMER_WARNING') || '';
+  return split(/;\s*/, $warning_value);
+} # warnings
+
+
+sub errors {
+  my $self = shift;
+  my $error_value = $self->run_parameter('PRIMER_ERROR') || '';
+  return split(/;\s*/, $error_value);
+} # errors
+
+
 sub rewind {
     my ($self, $it_type) = @_;
     return unless defined $it_type;
@@ -327,6 +342,8 @@ Bio::Tools::Primer3Redux::Result
 
     # parse a Primer3 report, and get Bio::Tools::Primer3Redux::Result
     while (my $result = $parser->next_result) {
+        (say "primer design failed" and next) if $result->errors;
+
         say $result->num_primer_pairs;
         my $pair = $result->next_primer_pair;
 
@@ -345,10 +362,18 @@ below for more on this).
 
 This parser will attach any lazily-generated features to that Bio::Seq object.
 The sequence can be retrieved via get_seq() at any point, such as prior to
-the end of a parse).
-To retrieve a sequence guaranteed to have all Primer/PrimerPair data
-attached, use get_processed_seq(). Switching seqs will cause a new batch of
-features to be generated and attached.
+the end of a parse). To retrieve a sequence guaranteed to have all
+Primer/PrimerPair data attached, use get_processed_seq(). Switching seqs will
+cause a new batch of features to be generated and attached.
+
+Please note that primer3 does not terminate on errors during primer design
+(e.g. due to input parameters that are impossible to fulfill).
+To check if errors or warnings were produced, it is recommended to always
+check the result object for errors like so:
+
+  if ($result->errors){
+    # handle the situation
+  }
 
 =head1 NAME
 
@@ -488,6 +513,22 @@ Internal methods are usually preceded with a _
  Returns  :
  Args     :
 
+=head2 warnings
+
+ Title   : warnings
+ Function: returns a list of the warning messages returned by primer3, if any
+ Usage   : my @warnings = $obj->warnings;
+ Args    : none
+ Returns : Array of messages
+
+=head2 errors
+
+ Title   : errors
+ Function: returns a list of the error messages returned by primer3, if any
+ Usage   : my @errors = $obj->errors;
+ Args    : none
+ Returns : Array of messages
+
 =head2 rewind
 
  Title    : rewind
